ClientBuilder

Struct ClientBuilder 

pub struct ClientBuilder { /* private fields */ }
A builder for creating Client instances with customizable configurations.

Implementations

Source

impl ClientBuilder

pub fn new() -> ClientBuilder

Creates a new ClientBuilder instance.

pub fn with_peers(self, peers: Vec<Peer>) -> ClientBuilder

Adds multiple peers to the client configuration.

pub fn with_peer(self, peer: Peer) -> ClientBuilder

Adds a single peer to the client configuration.

pub fn with_tools(self, tools: Vec<Tool>) -> ClientBuilder

Adds multiple tools to the client configuration. Use this to add local tools.

pub fn with_tool(self, tool: Tool) -> ClientBuilder

Adds a single tool to the client configuration. Use this to add a local tool.

pub fn with_capabilities( self, capabilities: ClientCapabilities, ) -> ClientBuilder

Sets the capabilities for the client.

pub async fn build(self) -> Result<Client, Error>

Builds the Client instance based on the configured parameters.

Errors

Returns an error if the peer list is empty or if there’s an issue retrieving peers.